Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(335)

Unified Diff: content/browser/cache_storage/cache_storage_quota_client.h

Issue 1039763002: Cache Storage: Move files to content/*/cache_storage, rename classes (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: GN fix Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/cache_storage/cache_storage_quota_client.h
diff --git a/content/browser/service_worker/service_worker_cache_quota_client.h b/content/browser/cache_storage/cache_storage_quota_client.h
similarity index 61%
rename from content/browser/service_worker/service_worker_cache_quota_client.h
rename to content/browser/cache_storage/cache_storage_quota_client.h
index 82111497b843e6e9bbf6e0cf5ad7d28dffbc6479..94df1d9f1a47cd43837d6614d45b3b77299a9a8f 100644
--- a/content/browser/service_worker/service_worker_cache_quota_client.h
+++ b/content/browser/cache_storage/cache_storage_quota_client.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_BROWSER_SERVICE_WORKER_SERVICE_WORKER_CACHE_QUOTA_CLIENT_H_
-#define CONTENT_BROWSER_SERVICE_WORKER_SERVICE_WORKER_CACHE_QUOTA_CLIENT_H_
+#ifndef CONTENT_BROWSER_CACHE_STORAGE_CACHE_STORAGE_QUOTA_CLIENT_H_
+#define CONTENT_BROWSER_CACHE_STORAGE_CACHE_STORAGE_QUOTA_CLIENT_H_
#include "base/memory/weak_ptr.h"
#include "content/common/content_export.h"
@@ -15,17 +15,16 @@ class QuotaManagerProxy;
}
namespace content {
-class ServiceWorkerCacheStorageManager;
+class CacheStorageManager;
-// ServiceWorkerCacheQuotaClient is owned by the QuotaManager. There is one per
-// ServiceWorkerCacheStorageManager, and therefore one per
+// CacheStorageQuotaClient is owned by the QuotaManager. There is one per
+// CacheStorageManager, and therefore one per
// ServiceWorkerContextCore.
-class CONTENT_EXPORT ServiceWorkerCacheQuotaClient
- : public storage::QuotaClient {
+class CONTENT_EXPORT CacheStorageQuotaClient : public storage::QuotaClient {
public:
- explicit ServiceWorkerCacheQuotaClient(
- base::WeakPtr<ServiceWorkerCacheStorageManager> cache_manager);
- ~ServiceWorkerCacheQuotaClient() override;
+ explicit CacheStorageQuotaClient(
+ base::WeakPtr<CacheStorageManager> cache_manager);
+ ~CacheStorageQuotaClient() override;
// QuotaClient overrides
ID id() const override;
@@ -44,11 +43,11 @@ class CONTENT_EXPORT ServiceWorkerCacheQuotaClient
bool DoesSupport(storage::StorageType type) const override;
private:
- base::WeakPtr<ServiceWorkerCacheStorageManager> cache_manager_;
+ base::WeakPtr<CacheStorageManager> cache_manager_;
- DISALLOW_COPY_AND_ASSIGN(ServiceWorkerCacheQuotaClient);
+ DISALLOW_COPY_AND_ASSIGN(CacheStorageQuotaClient);
};
} // namespace content
-#endif // CONTENT_BROWSER_SERVICE_WORKER_SERVICE_WORKER_CACHE_QUOTA_CLIENT_H_
+#endif // CONTENT_BROWSER_CACHE_STORAGE_CACHE_STORAGE_QUOTA_CLIENT_H_
« no previous file with comments | « content/browser/cache_storage/cache_storage_proto.gyp ('k') | content/browser/cache_storage/cache_storage_quota_client.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698